# MooCoderPy
Python/Tkinter version of Moocoder

Very much a work in progress, but it currently works as a simple Moo client.

Can be installed via pip:
* pip install moocoderpy-rjmatthews62
* python -m MooCoderPy

Setup -> Server Config : set server address (and port) 

File -> Connect - Connect to server
File -> Disconnect - Disconnect from server
File -> Open - Open a local file in the editor

